@@ -1,7 +1,7 @@
 package File::Create::Layout;
 
-our $DATE = '2015-09-11'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2016-03-16'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use strict;
@@ -34,8 +34,8 @@ _
 
 sub _decode_json {
     state $json = do {
-        require JSON;
-        JSON->new->allow_nonref;
+        require JSON::MaybeXS;
+        JSON::MaybeXS->new->allow_nonref;
     };
     $json->decode(shift);
 }
@@ -324,7 +324,7 @@ File::Create::Layout - Quickly create files/directories according to a layout
 
 =head1 VERSION
 
-This document describes version 0.03 of File::Create::Layout (from Perl distribution File-Create-Layout), released on 2015-09-11.
+This document describes version 0.04 of File::Create::Layout (from Perl distribution File-Create-Layout), released on 2016-03-16.
 
 =head1 SYNOPSIS
 
@@ -356,106 +356,6 @@ This document describes version 0.03 of File::Create::Layout (from Perl distribu
 B<EARLY DEVELOPMENT. MORE OPTIONS WILL BE AVAILABLE (E.G. DRY-RUN, CHECKING A
 LAYOUT AGAINST FILESYSTEM, VARIOUS ERROR HANDLING OPTIONS).>
 
-=head1 FUNCTIONS
-
-
-=head2 check_layout(%args) -> [status, msg, result, meta]
-
-Check whether layout has syntax errors.
-
-Arguments ('*' denotes required arguments):
-
-=over 4
-
-=item * B<layout>* => I<str>
-
-Layout.
-
-See the module documentation for the format/specification of layout.
-
-=back
-
-Returns an enveloped result (an array).
-
-First element (status) is an integer containing HTTP status code
-(200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
-
-Return value:  (any)
-
-
-=head2 create_files_using_layout(%args) -> [status, msg, result, meta]
-
-Create files/directories according to a layout.
-
-This routine can be used to quickly create several files/directories according
-to a layout which you specify. The layout uses a few simple rules and common
-conventions usually found in Linux/Unix environment.
-
-You can use this routine e.g. in a test script.
-
-Arguments ('*' denotes required arguments):
-
-=over 4
-
-=item * B<layout>* => I<str>
-
-Layout.
-
-See the module documentation for the format/specification of layout.
-
-=item * B<prefix> => I<str>
-
-Root directory to create the files/directories in.
-
-Directory must already exist.
-
-If unspecified, will simply create starting from current directory.
-
-=back
-
-Returns an enveloped result (an array).
-
-First element (status) is an integer containing HTTP status code
-(200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
-
-Return value:  (any)
-
-
-=head2 parse_layout(%args) -> [status, msg, result, meta]
-
-Parse layout string into a data structure suitable for processing.
-
-Arguments ('*' denotes required arguments):
-
-=over 4
-
-=item * B<layout>* => I<str>
-
-Layout.
-
-See the module documentation for the format/specification of layout.
-
-=back
-
-Returns an enveloped result (an array).
-
-First element (status) is an integer containing HTTP status code
-(200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
-
-Return value:  (any)
-
 =head1 LAYOUT SPECIFICATION
 
 Layout is a text document containing zero or more lines. Each line is either a
@@ -523,9 +423,111 @@ are not allowed) is used for this:
  file5-in-top-level
  file6
 
-=head1 SEE ALSO
+=head1 FUNCTIONS
 
-L<Setup::File::Layout>, transactional/undoable version of this module
+
+=head2 check_layout(%args) -> [status, msg, result, meta]
+
+Check whether layout has syntax errors.
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<layout>* => I<str>
+
+Layout.
+
+See the module documentation for the format/specification of layout.
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+=head2 create_files_using_layout(%args) -> [status, msg, result, meta]
+
+Create files/directories according to a layout.
+
+This routine can be used to quickly create several files/directories according
+to a layout which you specify. The layout uses a few simple rules and common
+conventions usually found in Linux/Unix environment.
+
+You can use this routine e.g. in a test script.
+
+This function is not exported by default, but exportable.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<layout>* => I<str>
+
+Layout.
+
+See the module documentation for the format/specification of layout.
+
+=item * B<prefix> => I<str>
+
+Root directory to create the files/directories in.
+
+Directory must already exist.
+
+If unspecified, will simply create starting from current directory.
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+=head2 parse_layout(%args) -> [status, msg, result, meta]
+
+Parse layout string into a data structure suitable for processing.
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<layout>* => I<str>
+
+Layout.
+
+See the module documentation for the format/specification of layout.
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
 
 =head1 HOMEPAGE
 
@@ -543,13 +545,17 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Setup::File::Layout>, transactional/undoable version of this module
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
